@@ -22,7 +22,6 @@ class SALUSDeviceHelper:
     def device_init(self, raw_device):
         device_id = raw_device["data"]["UniID"]
         device_model = raw_device["DeviceL"]["ModelIdentifier_i"]
-        print(device_model)
         if device_model in SUPPORTED_MODELS:
             device = build(api=self._api, raw_device=raw_device)
             self._devices_by_model[device_model][device_id] = device
@@ -32,6 +31,6 @@ class SALUSDeviceHelper:
 
     @property
     def thermostats(self) -> typing.Sequence[SALUSThermostat]:
-        if "Thermostat" not in SUPPORTED_MODELS:
+        if "SQ610RF" not in SUPPORTED_MODELS:
             return []
-        return list(self._devices_by_model["Thermostat"].values())
+        return list(self._devices_by_model["SQ610RF"].values())
